@@ -19,7 +19,7 @@ require 'faraday/dependency_loader'
 #   conn.get '/'
 #
 module Faraday
-  VERSION = '1.0.0'
+  VERSION = '1.0.1'
   METHODS_WITH_QUERY = %w[get head delete trace].freeze
   METHODS_WITH_BODY = %w[post put patch].freeze
 
@@ -153,7 +153,7 @@ module Faraday
     @default_connection_options = ConnectionOptions.from(options)
   end
 
-  unless const_defined? :Timer
+  unless defined?(::Faraday::Timer)
     require 'timeout'
     Timer = Timeout
   end
